@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-stats?lang_cible=pt_br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'stats_description' => 'Estatísticas do SPIP',
 	'stats_nom' => 'Estatísticas',
-	'stats_slogan' => 'Gerenciamento das estatísticas do SPIP'
-);
+	'stats_slogan' => 'Gerenciamento das estatísticas do SPIP',
+];
